@@ -70,6 +70,8 @@ checkfunc d_fchmodat 'fchmodat' "0,NULL,0,0" 'unistd.h'
 checkfunc d_fchown 'fchown' "0,0,0" 'unistd.h'
 checkfunc d_fcntl 'fcntl' "0,0" 'unistd.h fcntl.h'
 checkfunc d_fdclose 'fdclose'
+checkfunc d_ffs 'ffs' 'strings.h'
+checkfunc d_ffsl 'ffsl' 'strings.h'
 checkfunc d_fgetpos 'fgetpos' "NULL, 0" 'stdio.h'
 checkfunc d_flock 'flock' "0,0" 'unistd.h'
 checkfunc d_fork 'fork' "" 'unistd.h'
@@ -273,6 +275,7 @@ checkfunc d_strtoul 'strtoul' 'NULL,NULL,0'
 checkfunc d_strtoull 'strtoull' 'NULL,NULL,0'
 checkfunc d_strtouq 'strtouq'
 checkfunc d_strxfrm 'strxfrm'
+checkfunc d_strxfrm_l 'strxfrm_l'
 checkfunc d_symlink 'symlink'
 checkfunc d_syscall 'syscall'
 checkfunc d_sysconf 'sysconf' '0'
