@@ -103,11 +103,13 @@ checkhdr i_time 'time.h'
 checkhdr i_unistd 'unistd.h'
 checkhdr i_ustat 'ustat.h'
 checkhdr i_utime 'utime.h'
+checkhdr i_valgrind 'valgrind/valgrind.h' # cperl
 checkhdr i_values 'values.h'
 # i_varargs is checked below
 # i_varhdr is checked below
 checkhdr i_vfork 'vfork.h'
 checkhdr i_wchar 'wchar.h'
+checkhdr i_wctype 'wctype.h'
 checkhdr i_xlocale 'xlocale.h'
 checkhdr i_zlib 'zlib.h' # cperl, only to disable modules
 
