@@ -2,7 +2,7 @@
 
 tryprog() {
 	log "trying $1=$2"
-	if command -v "$2" 1>/dev/null 2>/dev/null; then
+	if command -v $2 1>/dev/null 2>/dev/null; then
 		define "$1" "$2"
 		result "$2"
 		return 0
@@ -189,15 +189,7 @@ fi
 # Use $ldflags as default value for $lddlflags, together with whatever
 # hints provided, but avoid re-setting anyting specified in the command line
 if [ -n "$ldflags" -a "$x_lddlflags" != "user" ]; then
-	msg "Checking which flags from \$ldflags to move to \$lddlflags"
-	for f in $ldflags; do
-		case "$f" in
-			-L*|-R*|-Wl,-R*)
-				msg "    added $f"
-				append lddlflags "$f"
-				;;
-		esac
-	done
+	append lddlflags "$ldflags"
 fi
 
 # enddef ccflags # done later in _hdrs because of LARGEFILE_SOURCE
